'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _graphql = require('graphql');

var _language = require('graphql/language');

function getObject(value) {
  return (typeof value === 'undefined' ? 'undefined' : _typeof(value)) === 'object' ? value : null;
}

function parseObject(ast) {
  switch (ast.kind) {
    case _language.Kind.STRING:
    case _language.Kind.BOOLEAN:
      return ast.value;
    case _language.Kind.INT:
    case _language.Kind.FLOAT:
      return parseFloat(ast.value);
    case _language.Kind.OBJECT:
      {
        var value = Object.create(null);
        ast.fields.forEach(function (field) {
          value[field.name.value] = parseObject(field.value);
        });
        return value;
      }
    case _language.Kind.LIST:
      return ast.values.map(parseObject);
    default:
      return null;
  }
}

exports.default = new _graphql.GraphQLScalarType({
  name: 'JSON_OBJECT',
  description: 'The `JSON_OBJECT` scalar type represents a JSON Object',
  serialize: getObject,
  parseValue: getObject,
  parseLiteral: function parseLiteral(ast) {
    return ast.kind === _language.Kind.OBJECT ? parseObject(ast) : null;
  }
});